Documentation
¶
Overview ¶
Package settings provides read-only access to a small number of host settings required for toolkits similar to XSettings. It is not for general purpose settings. Upstream API documentation can be found at https://flatpak.github.io/xdg-desktop-portal/docs/doc-org.freedesktop.portal.Settings.html.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func OnSignalSettingChanged ¶ added in v0.2.0
OnSignalSettingChanged listens for the SettingChanged signal. This signal is emitted when a setting changes.
Types ¶
Directories
¶
| Path | Synopsis |
|---|---|
|
Package appearance is a helper package for reading appearance settings.
|
Package appearance is a helper package for reading appearance settings. |
Click to show internal directories.
Click to hide internal directories.